;;; poke-line-types.el --- Provides Pokemon types used by `poke-line' -*- lexical-binding: t; -*-

;; Author: Ryan Miller <ryan@devopsmachine.com>
;; URL: https://github.com/RyanMillerC/poke-line/
;; Keywords: pokemon, fun, mode-line, mouse

;; This file is not part of GNU Emacs.

;; This program is free software; you can redistribute it and/or
;; modify it under the terms of the GNU General Public License as
;; published by the Free Software Foundation; either version 3, or
;; (at your option) any later version.
;;
;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
;; General Public License for more details.
;;
;; You should have received a copy of the GNU General Public License
;; along with this program; see the file COPYING.  If not, write to
;; the Free Software Foundation, Inc., 51 Franklin Street, Fifth
;; Floor, Boston, MA 02110-1301, USA.

;;; Commentary:

;; This package is required by poke-line to provide Pokemon types

;;; Code:

(defvar poke-line-pokemon-types '(("bulbasaur" . "grass")
                                  ("ivysaur" . "grass")
                                  ("venusaur" . "grass")
                                  ("charmander" . "fire")
                                  ("charmeleon" . "fire")
                                  ("charizard" . "fire")
                                  ("squirtle" . "water")
                                  ("wartortle" . "water")
                                  ("blastoise" . "water")
                                  ("caterpie" . "bug")
                                  ("metapod" . "bug")
                                  ("butterfree" . "bug")
                                  ("weedle" . "bug")
                                  ("kakuna" . "bug")
                                  ("beedrill" . "bug")
                                  ("pidgey" . "normal")
                                  ("pidgeotto" . "normal")
                                  ("pidgeot" . "normal")
                                  ("rattata" . "normal")
                                  ("raticate" . "normal")
                                  ("spearow" . "normal")
                                  ("fearow" . "normal")
                                  ("ekans" . "poison")
                                  ("arbok" . "poison")
                                  ("pikachu" . "electric")
                                  ("raichu" . "electric")
                                  ("sandshrew" . "ground")
                                  ("sandslash" . "ground")
                                  ("nidoran-m" . "poison")
                                  ("nidorina" . "poison")
                                  ("nidoqueen" . "poison")
                                  ("nidoran-f" . "poison")
                                  ("nidorino" . "poison")
                                  ("nidoking" . "poison")
                                  ("clefairy" . "fairy")
                                  ("clefable" . "fairy")
                                  ("vulpix" . "fire")
                                  ("ninetales" . "fire")
                                  ("jigglypuff" . "normal")
                                  ("wigglytuff" . "normal")
                                  ("zubat" . "poison")
                                  ("golbat" . "poison")
                                  ("oddish" . "grass")
                                  ("gloom" . "grass")
                                  ("vileplume" . "grass")
                                  ("paras" . "bug")
                                  ("parasect" . "bug")
                                  ("venonat" . "bug")
                                  ("venomoth" . "bug")
                                  ("diglett" . "ground")
                                  ("dugtrio" . "ground")
                                  ("meowth" . "normal")
                                  ("persian" . "normal")
                                  ("psyduck" . "water")
                                  ("golduck" . "water")
                                  ("mankey" . "fighting")
                                  ("primeape" . "fighting")
                                  ("growlithe" . "fire")
                                  ("arcanine" . "fire")
                                  ("poliwag" . "water")
                                  ("poliwhirl" . "water")
                                  ("poliwrath" . "water")
                                  ("abra" . "psychic")
                                  ("kadabra" . "psychic")
                                  ("alakazam" . "psychic")
                                  ("machop" . "fighting")
                                  ("machoke" . "fighting")
                                  ("machamp" . "fighting")
                                  ("bellsprout" . "grass")
                                  ("weepinbell" . "grass")
                                  ("victreebel" . "grass")
                                  ("tentacool" . "water")
                                  ("tentacruel" . "water")
                                  ("geodude" . "rock")
                                  ("graveler" . "rock")
                                  ("golem" . "rock")
                                  ("ponyta" . "fire")
                                  ("rapidash" . "fire")
                                  ("slowpoke" . "water")
                                  ("slowbro" . "water")
                                  ("magnemite" . "electric")
                                  ("magneton" . "electric")
                                  ("farfetchd" . "normal")
                                  ("doduo" . "normal")
                                  ("dodrio" . "normal")
                                  ("seel" . "water")
                                  ("dewgong" . "water")
                                  ("grimer" . "poison")
                                  ("muk" . "poison")
                                  ("shellder" . "water")
                                  ("cloyster" . "water")
                                  ("gastly" . "ghost")
                                  ("haunter" . "ghost")
                                  ("gengar" . "ghost")
                                  ("onix" . "rock")
                                  ("drowzee" . "psychic")
                                  ("hypno" . "psychic")
                                  ("krabby" . "water")
                                  ("kingler" . "water")
                                  ("voltorb" . "electric")
                                  ("electrode" . "electric")
                                  ("exeggcute" . "grass")
                                  ("exeggutor" . "grass")
                                  ("cubone" . "ground")
                                  ("marowak" . "ground")
                                  ("hitmonlee" . "fighting")
                                  ("hitmonchan" . "fighting")
                                  ("lickitung" . "normal")
                                  ("koffing" . "poison")
                                  ("weezing" . "poison")
                                  ("rhyhorn" . "ground")
                                  ("rhydon" . "ground")
                                  ("chansey" . "normal")
                                  ("tangela" . "grass")
                                  ("kangaskhan" . "normal")
                                  ("horsea" . "water")
                                  ("seadra" . "water")
                                  ("goldeen" . "water")
                                  ("seaking" . "water")
                                  ("staryu" . "water")
                                  ("starmie" . "water")
                                  ("mr mime" . "psychic")
                                  ("scyther" . "bug")
                                  ("jynx" . "ice")
                                  ("electabuzz" . "electric")
                                  ("magmar" . "fire")
                                  ("pinsir" . "bug")
                                  ("tauros" . "normal")
                                  ("magikarp" . "water")
                                  ("gyarados" . "water")
                                  ("lapras" . "water")
                                  ("ditto" . "normal")
                                  ("eevee" . "normal")
                                  ("vaporeon" . "water")
                                  ("jolteon" . "electric")
                                  ("flareon" . "fire")
                                  ("porygon" . "normal")
                                  ("omanyte" . "rock")
                                  ("omastar" . "rock")
                                  ("kabuto" . "rock")
                                  ("kabutops" . "rock")
                                  ("aerodactyl" . "rock")
                                  ("snorlax" . "normal")
                                  ("articuno" . "ice")
                                  ("zapdos" . "electric")
                                  ("moltres" . "fire")
                                  ("dratini" . "dragon")
                                  ("dragonair" . "dragon")
                                  ("dragonite" . "dragon")
                                  ("mewtwo" . "psychic")
                                  ("mew" . "psychic")
                                  ("chikorita" . "grass")
                                  ("bayleef" . "grass")
                                  ("meganium" . "grass")
                                  ("cyndaquil" . "fire")
                                  ("quilava" . "fire")
                                  ("typhlosion" . "fire")
                                  ("totodile" . "water")
                                  ("croconaw" . "water")
                                  ("feraligatr" . "water")
                                  ("sentret" . "normal")
                                  ("furret" . "normal")
                                  ("hoothoot" . "normal")
                                  ("noctowl" . "normal")
                                  ("ledyba" . "bug")
                                  ("ledian" . "bug")
                                  ("spinarak" . "bug")
                                  ("ariados" . "bug")
                                  ("crobat" . "poison")
                                  ("chinchou" . "water")
                                  ("lanturn" . "water")
                                  ("pichu" . "electric")
                                  ("cleffa" . "fairy")
                                  ("igglybuff" . "normal")
                                  ("togepi" . "fairy")
                                  ("togetic" . "fairy")
                                  ("natu" . "psychic")
                                  ("xatu" . "psychic")
                                  ("mareep" . "electric")
                                  ("flaaffy" . "electric")
                                  ("ampharos" . "electric")
                                  ("bellossom" . "grass")
                                  ("marill" . "water")
                                  ("azumarill" . "water")
                                  ("sudowoodo" . "rock")
                                  ("politoed" . "water")
                                  ("hoppip" . "grass")
                                  ("skiploom" . "grass")
                                  ("jumpluff" . "grass")
                                  ("aipom" . "normal")
                                  ("sunkern" . "grass")
                                  ("sunflora" . "grass")
                                  ("yanma" . "bug")
                                  ("wooper" . "water")
                                  ("quagsire" . "water")
                                  ("espeon" . "psychic")
                                  ("umbreon" . "dark")
                                  ("murkrow" . "dark")
                                  ("slowking" . "water")
                                  ("misdreavus" . "ghost")
                                  ("unown" . "psychic")
                                  ("wobbuffet" . "psychic")
                                  ("girafarig" . "normal")
                                  ("pineco" . "bug")
                                  ("forretress" . "bug")
                                  ("dunsparce" . "normal")
                                  ("gligar" . "ground")
                                  ("steelix" . "steel")
                                  ("snubbull" . "fairy")
                                  ("granbull" . "fairy")
                                  ("qwilfish" . "water")
                                  ("scizor" . "bug")
                                  ("shuckle" . "bug")
                                  ("heracross" . "bug")
                                  ("sneasel" . "dark")
                                  ("teddiursa" . "normal")
                                  ("ursaring" . "normal")
                                  ("slugma" . "fire")
                                  ("magcargo" . "fire")
                                  ("swinub" . "ice")
                                  ("piloswine" . "ice")
                                  ("corsola" . "water")
                                  ("remoraid" . "water")
                                  ("octillery" . "water")
                                  ("delibird" . "ice")
                                  ("mantine" . "water")
                                  ("skarmory" . "steel")
                                  ("houndour" . "dark")
                                  ("houndoom" . "dark")
                                  ("kingdra" . "water")
                                  ("phanpy" . "ground")
                                  ("donphan" . "ground")
                                  ("porygon2" . "normal")
                                  ("stantler" . "normal")
                                  ("smeargle" . "normal")
                                  ("tyrogue" . "fighting")
                                  ("hitmontop" . "fighting")
                                  ("smoochum" . "ice")
                                  ("elekid" . "electric")
                                  ("magby" . "fire")
                                  ("miltank" . "normal")
                                  ("blissey" . "normal")
                                  ("raikou" . "electric")
                                  ("entei" . "fire")
                                  ("suicune" . "water")
                                  ("larvitar" . "rock")
                                  ("pupitar" . "rock")
                                  ("tyranitar" . "rock")
                                  ("lugia" . "psychic")
                                  ("ho-oh" . "fire")
                                  ("celebi" . "psychic")
                                  ("treecko" . "grass")
                                  ("grovyle" . "grass")
                                  ("sceptile" . "grass")
                                  ("torchic" . "fire")
                                  ("combusken" . "fire")
                                  ("blaziken" . "fire")
                                  ("mudkip" . "water")
                                  ("marshtomp" . "water")
                                  ("swampert" . "water")
                                  ("poochyena" . "dark")
                                  ("mightyena" . "dark")
                                  ("zigzagoon" . "normal")
                                  ("linoone" . "normal")
                                  ("wurmple" . "bug")
                                  ("silcoon" . "bug")
                                  ("beautifly" . "bug")
                                  ("cascoon" . "bug")
                                  ("dustox" . "bug")
                                  ("lotad" . "water")
                                  ("lombre" . "water")
                                  ("ludicolo" . "water")
                                  ("seedot" . "grass")
                                  ("nuzleaf" . "grass")
                                  ("shiftry" . "grass")
                                  ("taillow" . "normal")
                                  ("swellow" . "normal")
                                  ("wingull" . "water")
                                  ("pelipper" . "water")
                                  ("ralts" . "psychic")
                                  ("kirlia" . "psychic")
                                  ("gardevoir" . "psychic")
                                  ("surskit" . "bug")
                                  ("masquerain" . "bug")
                                  ("shroomish" . "grass")
                                  ("breloom" . "grass")
                                  ("slakoth" . "normal")
                                  ("vigoroth" . "normal")
                                  ("slaking" . "normal")
                                  ("nincada" . "bug")
                                  ("ninjask" . "bug")
                                  ("shedinja" . "bug")
                                  ("whismur" . "normal")
                                  ("loudred" . "normal")
                                  ("exploud" . "normal")
                                  ("makuhita" . "fighting")
                                  ("hariyama" . "fighting")
                                  ("azurill" . "normal")
                                  ("nosepass" . "rock")
                                  ("skitty" . "normal")
                                  ("delcatty" . "normal")
                                  ("sableye" . "dark")
                                  ("mawile" . "steel")
                                  ("aron" . "steel")
                                  ("lairon" . "steel")
                                  ("aggron" . "steel")
                                  ("meditite" . "fighting")
                                  ("medicham" . "fighting")
                                  ("electrike" . "electric")
                                  ("manectric" . "electric")
                                  ("plusle" . "electric")
                                  ("minun" . "electric")
                                  ("volbeat" . "bug")
                                  ("illumise" . "bug")
                                  ("roselia" . "grass")
                                  ("gulpin" . "poison")
                                  ("swalot" . "poison")
                                  ("carvanha" . "water")
                                  ("sharpedo" . "water")
                                  ("wailmer" . "water")
                                  ("wailord" . "water")
                                  ("numel" . "fire")
                                  ("camerupt" . "fire")
                                  ("torkoal" . "fire")
                                  ("spoink" . "psychic")
                                  ("grumpig" . "psychic")
                                  ("spinda" . "normal")
                                  ("trapinch" . "ground")
                                  ("vibrava" . "ground")
                                  ("flygon" . "ground")
                                  ("cacnea" . "grass")
                                  ("cacturne" . "grass")
                                  ("swablu" . "normal")
                                  ("altaria" . "dragon")
                                  ("zangoose" . "normal")
                                  ("seviper" . "poison")
                                  ("lunatone" . "rock")
                                  ("solrock" . "rock")
                                  ("barboach" . "water")
                                  ("whiscash" . "water")
                                  ("corphish" . "water")
                                  ("crawdaunt" . "water")
                                  ("baltoy" . "ground")
                                  ("claydol" . "ground")
                                  ("lileep" . "rock")
                                  ("cradily" . "rock")
                                  ("anorith" . "rock")
                                  ("armaldo" . "rock")
                                  ("feebas" . "water")
                                  ("milotic" . "water")
                                  ("castform" . "normal")
                                  ("kecleon" . "normal")
                                  ("shuppet" . "ghost")
                                  ("banette" . "ghost")
                                  ("duskull" . "ghost")
                                  ("dusclops" . "ghost")
                                  ("tropius" . "grass")
                                  ("chimecho" . "psychic")
                                  ("absol" . "dark")
                                  ("wynaut" . "psychic")
                                  ("snorunt" . "ice")
                                  ("glalie" . "ice")
                                  ("spheal" . "ice")
                                  ("sealeo" . "ice")
                                  ("walrein" . "ice")
                                  ("clamperl" . "water")
                                  ("huntail" . "water")
                                  ("gorebyss" . "water")
                                  ("relicanth" . "water")
                                  ("luvdisc" . "water")
                                  ("bagon" . "dragon")
                                  ("shelgon" . "dragon")
                                  ("salamence" . "dragon")
                                  ("beldum" . "steel")
                                  ("metang" . "steel")
                                  ("metagross" . "steel")
                                  ("regirock" . "rock")
                                  ("regice" . "ice")
                                  ("registeel" . "steel")
                                  ("latias" . "dragon")
                                  ("latios" . "dragon")
                                  ("kyogre" . "water")
                                  ("groudon" . "ground")
                                  ("rayquaza" . "dragon")
                                  ("jirachi" . "steel")
                                  ("deoxys" . "psychic")
                                  ("turtwig" . "grass")
                                  ("grotle" . "grass")
                                  ("torterra" . "grass")
                                  ("chimchar" . "fire")
                                  ("monferno" . "fire")
                                  ("infernape" . "fire")
                                  ("piplup" . "water")
                                  ("prinplup" . "water")
                                  ("empoleon" . "water")
                                  ("starly" . "normal")
                                  ("staravia" . "normal")
                                  ("staraptor" . "normal")
                                  ("bidoof" . "normal")
                                  ("bibarel" . "normal")
                                  ("kricketot" . "bug")
                                  ("kricketune" . "bug")
                                  ("shinx" . "electric")
                                  ("luxio" . "electric")
                                  ("luxray" . "electric")
                                  ("budew" . "grass")
                                  ("roserade" . "grass")
                                  ("cranidos" . "rock")
                                  ("rampardos" . "rock")
                                  ("shieldon" . "rock")
                                  ("bastiodon" . "rock")
                                  ("burmy" . "bug")
                                  ("wormadam" . "bug")
                                  ("mothim" . "bug")
                                  ("combee" . "bug")
                                  ("vespiquen" . "bug")
                                  ("pachirisu" . "electric")
                                  ("buizel" . "water")
                                  ("floatzel" . "water")
                                  ("cherubi" . "grass")
                                  ("cherrim" . "grass")
                                  ("shellos" . "water")
                                  ("gastrodon" . "water")
                                  ("ambipom" . "normal")
                                  ("drifloon" . "ghost")
                                  ("drifblim" . "ghost")
                                  ("buneary" . "normal")
                                  ("lopunny" . "normal")
                                  ("mismagius" . "ghost")
                                  ("honchkrow" . "dark")
                                  ("glameow" . "normal")
                                  ("purugly" . "normal")
                                  ("chingling" . "psychic")
                                  ("stunky" . "poison")
                                  ("skuntank" . "poison")
                                  ("bronzor" . "steel")
                                  ("bronzong" . "steel")
                                  ("bonsly" . "rock")
                                  ("mime jr" . "psychic")
                                  ("happiny" . "normal")
                                  ("chatot" . "normal")
                                  ("spiritomb" . "ghost")
                                  ("gible" . "dragon")
                                  ("gabite" . "dragon")
                                  ("garchomp" . "dragon")
                                  ("munchlax" . "normal")
                                  ("riolu" . "fighting")
                                  ("lucario" . "fighting")
                                  ("hippopotas" . "ground")
                                  ("hippowdon" . "ground")
                                  ("skorupi" . "poison")
                                  ("drapion" . "poison")
                                  ("croagunk" . "poison")
                                  ("toxicroak" . "poison")
                                  ("carnivine" . "grass")
                                  ("finneon" . "water")
                                  ("lumineon" . "water")
                                  ("mantyke" . "water")
                                  ("snover" . "grass")
                                  ("abomasnow" . "grass")
                                  ("weavile" . "dark")
                                  ("magnezone" . "electric")
                                  ("lickilicky" . "normal")
                                  ("rhyperior" . "ground")
                                  ("tangrowth" . "grass")
                                  ("electivire" . "electric")
                                  ("magmortar" . "fire")
                                  ("togekiss" . "fairy")
                                  ("yanmega" . "bug")
                                  ("leafeon" . "grass")
                                  ("glaceon" . "ice")
                                  ("gliscor" . "ground")
                                  ("mamoswine" . "ice")
                                  ("porygon-z" . "normal")
                                  ("gallade" . "psychic")
                                  ("probopass" . "rock")
                                  ("dusknoir" . "ghost")
                                  ("froslass" . "ice")
                                  ("rotom" . "electric")
                                  ("uxie" . "psychic")
                                  ("mesprit" . "psychic")
                                  ("azelf" . "psychic")
                                  ("dialga" . "steel")
                                  ("palkia" . "water")
                                  ("heatran" . "fire")
                                  ("regigigas" . "normal")
                                  ("giratina" . "ghost")
                                  ("cresselia" . "psychic")
                                  ("phione" . "water")
                                  ("manaphy" . "water")
                                  ("darkrai" . "dark")
                                  ("shaymin" . "grass")
                                  ("arceus" . "normal")
                                  ("victini" . "psychic")
                                  ("snivy" . "grass")
                                  ("servine" . "grass")
                                  ("serperior" . "grass")
                                  ("tepig" . "fire")
                                  ("pignite" . "fire")
                                  ("emboar" . "fire")
                                  ("oshawott" . "water")
                                  ("dewott" . "water")
                                  ("samurott" . "water")
                                  ("patrat" . "normal")
                                  ("watchog" . "normal")
                                  ("lillipup" . "normal")
                                  ("herdier" . "normal")
                                  ("stoutland" . "normal")
                                  ("purrloin" . "dark")
                                  ("liepard" . "dark")
                                  ("pansage" . "grass")
                                  ("simisage" . "grass")
                                  ("pansear" . "fire")
                                  ("simisear" . "fire")
                                  ("panpour" . "water")
                                  ("simipour" . "water")
                                  ("munna" . "psychic")
                                  ("musharna" . "psychic")
                                  ("pidove" . "normal")
                                  ("tranquill" . "normal")
                                  ("unfezant" . "normal")
                                  ("blitzle" . "electric")
                                  ("zebstrika" . "electric")
                                  ("roggenrola" . "rock")
                                  ("boldore" . "rock")
                                  ("gigalith" . "rock")
                                  ("woobat" . "psychic")
                                  ("swoobat" . "psychic")
                                  ("drilbur" . "ground")
                                  ("excadrill" . "ground")
                                  ("audino" . "normal")
                                  ("timburr" . "fighting")
                                  ("gurdurr" . "fighting")
                                  ("conkeldurr" . "fighting")
                                  ("tympole" . "water")
                                  ("palpitoad" . "water")
                                  ("seismitoad" . "water")
                                  ("throh" . "fighting")
                                  ("sawk" . "fighting")
                                  ("sewaddle" . "bug")
                                  ("swadloon" . "bug")
                                  ("leavanny" . "bug")
                                  ("venipede" . "bug")
                                  ("whirlipede" . "bug")
                                  ("scolipede" . "bug")
                                  ("cottonee" . "grass")
                                  ("whimsicott" . "grass")
                                  ("petilil" . "grass")
                                  ("lilligant" . "grass")
                                  ("basculin" . "water")
                                  ("sandile" . "ground")
                                  ("krokorok" . "ground")
                                  ("krookodile" . "ground")
                                  ("darumaka" . "fire")
                                  ("darmanitan" . "fire")
                                  ("maractus" . "grass")
                                  ("dwebble" . "bug")
                                  ("crustle" . "bug")
                                  ("scraggy" . "dark")
                                  ("scrafty" . "dark")
                                  ("sigilyph" . "psychic")
                                  ("yamask" . "ghost")
                                  ("cofagrigus" . "ghost")
                                  ("tirtouga" . "water")
                                  ("carracosta" . "water")
                                  ("archen" . "rock")
                                  ("archeops" . "rock")
                                  ("trubbish" . "poison")
                                  ("garbodor" . "poison")
                                  ("zorua" . "dark")
                                  ("zoroark" . "dark")
                                  ("minccino" . "normal")
                                  ("cinccino" . "normal")
                                  ("gothita" . "psychic")
                                  ("gothorita" . "psychic")
                                  ("gothitelle" . "psychic")
                                  ("solosis" . "psychic")
                                  ("duosion" . "psychic")
                                  ("reuniclus" . "psychic")
                                  ("ducklett" . "water")
                                  ("swanna" . "water")
                                  ("vanillite" . "ice")
                                  ("vanillish" . "ice")
                                  ("vanilluxe" . "ice")
                                  ("deerling" . "normal")
                                  ("sawsbuck" . "normal")
                                  ("emolga" . "electric")
                                  ("karrablast" . "bug")
                                  ("escavalier" . "bug")
                                  ("foongus" . "grass")
                                  ("amoonguss" . "grass")
                                  ("frillish" . "water")
                                  ("jellicent" . "water")
                                  ("alomomola" . "water")
                                  ("joltik" . "bug")
                                  ("galvantula" . "bug")
                                  ("ferroseed" . "grass")
                                  ("ferrothorn" . "grass")
                                  ("klink" . "steel")
                                  ("klang" . "steel")
                                  ("klinklang" . "steel")
                                  ("tynamo" . "electric")
                                  ("eelektrik" . "electric")
                                  ("eelektross" . "electric")
                                  ("elgyem" . "psychic")
                                  ("beheeyem" . "psychic")
                                  ("litwick" . "ghost")
                                  ("lampent" . "ghost")
                                  ("chandelure" . "ghost")
                                  ("axew" . "dragon")
                                  ("fraxure" . "dragon")
                                  ("haxorus" . "dragon")
                                  ("cubchoo" . "ice")
                                  ("beartic" . "ice")
                                  ("cryogonal" . "ice")
                                  ("shelmet" . "bug")
                                  ("accelgor" . "bug")
                                  ("stunfisk" . "ground")
                                  ("mienfoo" . "fighting")
                                  ("mienshao" . "fighting")
                                  ("druddigon" . "dragon")
                                  ("golett" . "ground")
                                  ("golurk" . "ground")
                                  ("pawniard" . "dark")
                                  ("bisharp" . "dark")
                                  ("bouffalant" . "normal")
                                  ("rufflet" . "normal")
                                  ("braviary" . "normal")
                                  ("vullaby" . "dark")
                                  ("mandibuzz" . "dark")
                                  ("heatmor" . "fire")
                                  ("durant" . "bug")
                                  ("deino" . "dark")
                                  ("zweilous" . "dark")
                                  ("hydreigon" . "dark")
                                  ("larvesta" . "bug")
                                  ("volcarona" . "bug")
                                  ("cobalion" . "steel")
                                  ("terrakion" . "rock")
                                  ("virizion" . "grass")
                                  ("tornadus" . "flying")
                                  ("thundurus" . "electric")
                                  ("reshiram" . "dragon")
                                  ("zekrom" . "dragon")
                                  ("landorus" . "ground")
                                  ("kyurem" . "dragon")
                                  ("keldeo" . "water")
                                  ("meloetta" . "normal")
                                  ("genesect" . "bug")
                                  ("chespin" . "grass")
                                  ("quilladin" . "grass")
                                  ("chesnaught" . "grass")
                                  ("fennekin" . "fire")
                                  ("braixen" . "fire")
                                  ("delphox" . "fire")
                                  ("froakie" . "water")
                                  ("frogadier" . "water")
                                  ("greninja" . "water")
                                  ("bunnelby" . "normal")
                                  ("diggersby" . "normal")
                                  ("fletchling" . "normal")
                                  ("fletchinder" . "fire")
                                  ("talonflame" . "fire")
                                  ("scatterbug" . "bug")
                                  ("spewpa" . "bug")
                                  ("vivillon" . "bug")
                                  ("litleo" . "fire")
                                  ("pyroar" . "fire")
                                  ("flabebe" . "fairy")
                                  ("floette" . "fairy")
                                  ("florges" . "fairy")
                                  ("skiddo" . "grass")
                                  ("gogoat" . "grass")
                                  ("pancham" . "fighting")
                                  ("pangoro" . "fighting")
                                  ("furfrou" . "normal")
                                  ("espurr" . "psychic")
                                  ("meowstic" . "psychic")
                                  ("honedge" . "steel")
                                  ("doublade" . "steel")
                                  ("aegislash" . "steel")
                                  ("spritzee" . "fairy")
                                  ("aromatisse" . "fairy")
                                  ("swirlix" . "fairy")
                                  ("slurpuff" . "fairy")
                                  ("inkay" . "dark")
                                  ("malamar" . "dark")
                                  ("binacle" . "rock")
                                  ("barbaracle" . "rock")
                                  ("skrelp" . "poison")
                                  ("dragalge" . "poison")
                                  ("clauncher" . "water")
                                  ("clawitzer" . "water")
                                  ("helioptile" . "electric")
                                  ("heliolisk" . "electric")
                                  ("tyrunt" . "rock")
                                  ("tyrantrum" . "rock")
                                  ("amaura" . "rock")
                                  ("aurorus" . "rock")
                                  ("sylveon" . "fairy")
                                  ("hawlucha" . "fighting")
                                  ("dedenne" . "electric")
                                  ("carbink" . "rock")
                                  ("goomy" . "dragon")
                                  ("sliggoo" . "dragon")
                                  ("goodra" . "dragon")
                                  ("klefki" . "steel")
                                  ("phantump" . "ghost")
                                  ("trevenant" . "ghost")
                                  ("pumpkaboo" . "ghost")
                                  ("gourgeist" . "ghost")
                                  ("bergmite" . "ice")
                                  ("avalugg" . "ice")
                                  ("noibat" . "flying")
                                  ("noivern" . "flying")
                                  ("xerneas" . "fairy")
                                  ("yveltal" . "dark")
                                  ("zygarde" . "dragon")
                                  ("diancie" . "rock")
                                  ("hoopa" . "psychic")
                                  ("volcanion" . "fire")
                                  ("rowlet" . "grass")
                                  ("dartrix" . "grass")
                                  ("decidueye" . "grass")
                                  ("litten" . "fire")
                                  ("torracat" . "fire")
                                  ("incineroar" . "fire")
                                  ("popplio" . "water")
                                  ("brionne" . "water")
                                  ("primarina" . "water")
                                  ("pikipek" . "normal")
                                  ("trumbeak" . "normal")
                                  ("toucannon" . "normal")
                                  ("yungoos" . "normal")
                                  ("gumshoos" . "normal")
                                  ("grubbin" . "bug")
                                  ("charjabug" . "bug")
                                  ("vikavolt" . "bug")
                                  ("crabrawler" . "fighting")
                                  ("crabominable" . "fighting")
                                  ("oricorio" . "fire")
                                  ("cutiefly" . "bug")
                                  ("ribombee" . "bug")
                                  ("rockruff" . "rock")
                                  ("lycanroc" . "rock")
                                  ("wishiwashi" . "water")
                                  ("mareanie" . "poison")
                                  ("toxapex" . "poison")
                                  ("mudbray" . "ground")
                                  ("mudsdale" . "ground")
                                  ("dewpider" . "water")
                                  ("araquanid" . "water")
                                  ("fomantis" . "grass")
                                  ("lurantis" . "grass")
                                  ("morelull" . "grass")
                                  ("shiinotic" . "grass")
                                  ("salandit" . "poison")
                                  ("salazzle" . "poison")
                                  ("stufful" . "normal")
                                  ("bewear" . "normal")
                                  ("bounsweet" . "grass")
                                  ("steenee" . "grass")
                                  ("tsareena" . "grass")
                                  ("comfey" . "fairy")
                                  ("oranguru" . "normal")
                                  ("passimian" . "fighting")
                                  ("wimpod" . "bug")
                                  ("golisopod" . "bug")
                                  ("sandygast" . "ghost")
                                  ("palossand" . "ghost")
                                  ("pyukumuku" . "water")
                                  ("type-null" . "normal")
                                  ("silvally" . "normal")
                                  ("minior" . "rock")
                                  ("komala" . "normal")
                                  ("turtonator" . "fire")
                                  ("togedemaru" . "electric")
                                  ("mimikyu" . "ghost")
                                  ("bruxish" . "water")
                                  ("drampa" . "normal")
                                  ("dhelmise" . "ghost")
                                  ("jangmo-o" . "dragon")
                                  ("hakamo-o" . "dragon")
                                  ("kommo-o" . "dragon")
                                  ("tapu koko" . "electric")
                                  ("tapu lele" . "psychic")
                                  ("tapu bulu" . "grass")
                                  ("tapu fini" . "water")
                                  ("cosmog" . "psychic")
                                  ("cosmoem" . "psychic")
                                  ("solgaleo" . "psychic")
                                  ("lunala" . "psychic")
                                  ("nihilego" . "rock")
                                  ("buzzwole" . "bug")
                                  ("pheromosa" . "bug")
                                  ("xurkitree" . "electric")
                                  ("celesteela" . "steel")
                                  ("kartana" . "grass")
                                  ("guzzlord" . "dark")
                                  ("necrozma" . "psychic")
                                  ("magearna" . "steel")
                                  ("marshadow" . "fighting")
                                  ("poipole" . "poison")
                                  ("naganadel" . "poison")
                                  ("stakataka" . "rock")
                                  ("blacephalon" . "fire")
                                  ("zeraora" . "electric")
                                  ("meltan" . "steel")
                                  ("melmetal" . "steel")
                                  ("grookey" . "grass")
                                  ("thwackey" . "grass")
                                  ("rillaboom" . "grass")
                                  ("scorbunny" . "fire")
                                  ("raboot" . "fire")
                                  ("cinderace" . "fire")
                                  ("sobble" . "water")
                                  ("drizzile" . "water")
                                  ("inteleon" . "water")
                                  ("skwovet" . "normal")
                                  ("greedent" . "normal")
                                  ("rookidee" . "flying")
                                  ("corvisquire" . "flying")
                                  ("corviknight" . "flying")
                                  ("blipbug" . "bug")
                                  ("dottler" . "bug")
                                  ("orbeetle" . "bug")
                                  ("nickit" . "dark")
                                  ("thievul" . "dark")
                                  ("gossifleur" . "grass")
                                  ("eldegoss" . "grass")
                                  ("wooloo" . "normal")
                                  ("dubwool" . "normal")
                                  ("chewtle" . "water")
                                  ("drednaw" . "water")
                                  ("yamper" . "electric")
                                  ("boltund" . "electric")
                                  ("rolycoly" . "rock")
                                  ("carkol" . "rock")
                                  ("coalossal" . "rock")
                                  ("applin" . "grass")
                                  ("flapple" . "grass")
                                  ("appletun" . "grass")
                                  ("silicobra" . "ground")
                                  ("sandaconda" . "ground")
                                  ("cramorant" . "flying")
                                  ("arrokuda" . "water")
                                  ("barraskewda" . "water")
                                  ("toxel" . "electric")
                                  ("toxtricity" . "electric")
                                  ("sizzlipede" . "fire")
                                  ("centiskorch" . "fire")
                                  ("clobbopus" . "fighting")
                                  ("grapploct" . "fighting")
                                  ("sinistea" . "ghost")
                                  ("polteageist" . "ghost")
                                  ("hatenna" . "psychic")
                                  ("hattrem" . "psychic")
                                  ("hatterene" . "psychic")
                                  ("impidimp" . "dark")
                                  ("morgrem" . "dark")
                                  ("grimmsnarl" . "dark")
                                  ("obstagoon" . "dark")
                                  ("perrserker" . "steel")
                                  ("cursola" . "ghost")
                                  ("sirfetchd" . "fighting")
                                  ("mr rime" . "ice")
                                  ("runerigus" . "ground")
                                  ("milcery" . "fairy")
                                  ("alcremie" . "fairy")
                                  ("falinks" . "fighting")
                                  ("pincurchin" . "electric")
                                  ("snom" . "ice")
                                  ("frosmoth" . "ice")
                                  ("stonjourner" . "rock")
                                  ("eiscue" . "ice")
                                  ("indeedee" . "psychic")
                                  ("morpeko" . "electric")
                                  ("cufant" . "steel")
                                  ("copperajah" . "steel")
                                  ("dracozolt" . "electric")
                                  ("arctozolt" . "electric")
                                  ("dracovish" . "water")
                                  ("arctovish" . "water")
                                  ("duraludon" . "steel")
                                  ("dreepy" . "dragon")
                                  ("drakloak" . "dragon")
                                  ("dragapult" . "dragon")
                                  ("zacian" . "fairy")
                                  ("zamazenta" . "fighting")
                                  ("eternatus" . "poison")))

(provide 'poke-line-types)

;;; poke-line-types.el ends here
